@@ -248,3 +248,23 @@ def perform(func, data, func_args=None, asynch=False, workers=None, progress=Fal
         for index_or_item in elements:
             returned.append(func(index_or_item))
     return returned
+
+
+def schedule_job(func, blocking=False, **kwargs):
+    """
+    :param func: 定时任务
+    :param kwargs:
+            trigger: 'interval' 时间间隔型任务 kwargs: seconds
+                     'cron' 定时任务  kwargs: hour/minute
+    :return:
+    """
+
+    if not blocking:
+        from apscheduler.schedulers.background import BackgroundScheduler
+        scheduler = BackgroundScheduler()
+    else:
+        from apscheduler.schedulers.blocking import BlockingScheduler
+        scheduler = BlockingScheduler()
+
+    scheduler.add_job(func, **kwargs)
+    scheduler.start()
